@@ -18,8 +18,8 @@ PROCESS_XML = (
                 '<OrderId>{order_id}</OrderId>'
                 '<DateTime>{date_time}</DateTime>'
                 '<Transporter>'
-                    '<Code>{code}</Code>'
-                    '<TrackAndTraceCode>{transporter_code}</TrackAndTraceCode>'
+                    '<Code>{transporter_code}</Code>'
+                    '<TrackAndTraceCode>{code}</TrackAndTraceCode>'
                 '</Transporter>'
                 '<OrderItems>'
                     '{order_item_ids}'
